componenttools.Component
========================

.. inheritance-diagram:: abjad.tools.componenttools.Component.Component.Component
   :private-bases:

.. autoclass:: abjad.tools.componenttools.Component.Component.Component

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.format

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.marks

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.override

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.parent

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.prolated_duration

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.prolation

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.set

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.spanners

Special Methods
---------------

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__mul__

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__repr__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__rmul__

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__str__

   .. note:: Inherited from `__builtin__.object`
